x
- an object of class matrix (or which can be coerced to that class),
where each column represents the distribution of a population group, within
spatial units. The number of columns should be greater than 1 (at least 2
population groups are required). You should not include a column with total
totals because this will be interpreted as a population group