Arguments
spatobj
- a spatial object (SpatialPolygonsDataFrame) containing
geographic information
folder
- a character vector with the folder (directory)
name indicating where the shapefile with the geographic information
is located.
shape
- a character vector with the name of the shapefile
(without the .shp extension) which contains the geographic information
center
- the row number of the center
distin
- input metric conversion, based on bink package and
includes conversions from 'm', 'km', 'inch', 'ft', 'yd', 'mi', 'naut_mi', etc.
distout
- output metric conversion, based on bink package and
includes conversions to 'm', 'km', 'inch', 'ft', 'yd', 'mi', 'naut_mi', etc.